@@ -68,13 +68,13 @@ pub fn send_notificaion_via_connection(notification: &Notification, id: u32, con
                 &notification.summary,
                 &notification.body,
                 &notification.actions,
-                crate::hints::hints_to_map(&notification.hints),
+                crate::hints::hints_to_map(&notification),
                 notification.timeout.into_i32(),
             ),
         )?
         .body()
         .unwrap();
-    Ok(dbg!(reply))
+    Ok(reply)
 }
 
 pub fn connect_and_send_notification(notification: &Notification) -> Result<ZbusNotificationHandle> {
@@ -152,7 +152,10 @@ where
                         _ => {}
                     },
                     Ok(Some("NotificationClosed")) => match msg.body::<(u32, u32)>() {
-                        Ok((nid, _)) if nid == id => break,
+                        Ok((nid, _reason)) if nid == id => {
+                            func("__closed");
+                            break;
+                        }
                         _ => {}
                     },
 
